Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/config
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2021-01-14 09:11:16 +0300
committerGitLab Bot <gitlab-bot@gitlab.com>2021-01-14 09:11:16 +0300
commit298ae510cefeae8a8ffb9a868fefd9eceeac4122 (patch)
tree874a874b5d4117b97c9fd8475d76b9aa7dc966ce /config
parent04698e448a10aedea2f3ed37ffd0327e9b91426e (diff)
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'config')
-rw-r--r--config/feature_flags/development/optional_code_owners_sections.yml2
-rw-r--r--config/feature_flags/ops/scalability_ci_fetch_sha.yml8
-rw-r--r--config/initializers/carrierwave_patch.rb4
3 files changed, 12 insertions, 2 deletions
diff --git a/config/feature_flags/development/optional_code_owners_sections.yml b/config/feature_flags/development/optional_code_owners_sections.yml
index d97d5d8b701..a7933f42fc9 100644
--- a/config/feature_flags/development/optional_code_owners_sections.yml
+++ b/config/feature_flags/development/optional_code_owners_sections.yml
@@ -5,4 +5,4 @@ rollout_issue_url:
milestone: '13.8'
type: development
group: group::source code
-default_enabled: false
+default_enabled: true
diff --git a/config/feature_flags/ops/scalability_ci_fetch_sha.yml b/config/feature_flags/ops/scalability_ci_fetch_sha.yml
new file mode 100644
index 00000000000..e8133f16072
--- /dev/null
+++ b/config/feature_flags/ops/scalability_ci_fetch_sha.yml
@@ -0,0 +1,8 @@
+---
+name: scalability_ci_fetch_sha
+introduced_by_url: https://gitlab.com/gitlab-org/gitlab/-/merge_requests/51208
+rollout_issue_url: https://gitlab.com/gitlab-com/gl-infra/scalability/-/issues/746
+milestone: '13.8'
+type: ops
+group: team::Scalability
+default_enabled: false
diff --git a/config/initializers/carrierwave_patch.rb b/config/initializers/carrierwave_patch.rb
index a5102696251..c8c6f75949c 100644
--- a/config/initializers/carrierwave_patch.rb
+++ b/config/initializers/carrierwave_patch.rb
@@ -23,7 +23,9 @@ module CarrierWave
# Multithreaded uploads are essential for copying large amounts of data
# within the request timeout.
if ::Feature.enabled?(:s3_multithreaded_uploads, default_enabled: true) && fog_provider == 'AWS'
- file.concurrency = 10 # AWS SDK uses 10 threads by default
+ # AWS SDK uses 10 threads by default and a multipart chunk size of 10 MB
+ file.concurrency = 10
+ file.multipart_chunk_size = 10485760
file.copy(@uploader.fog_directory, new_path, copy_to_options)
else
# Some Fog providers may issue a GET request (https://github.com/fog/fog-google/issues/512)